@@ -14,8 +14,30 @@ class QGENAPI:
 	def __init__(self, qps_api):
 		self.qps_api = qps_api
 
+		self.http_timeout = 2
+		self.http_max_retries = 3
+
 		return
 
+	def http_post(self, url, headers, json):
+		timeout_counter = 0
+
+		while True:
+			try:
+				status_response = requests.post(url = url, headers = headers, json = json, timeout = self.http_timeout)
+			except Exception as e:
+				if(type(e) == requests.exceptions.ConnectTimeout):
+					timeout_counter += 1
+
+					if(timeout_counter >= self.http_max_retries):
+						raise
+				else:
+					raise
+			else:
+				status_response.raise_for_status()
+
+				return status_response
+
 	def solve(self, problem, settings = {}, start_job=True):
 		if("settings" not in problem):
 			problem["settings"] = {}
@@ -36,7 +58,7 @@ class QGENAPI:
 		#
 		create_url = _urljoin(self.qps_api.api_url, "generator", "job", "create")
 
-		create_response = requests.post(url = create_url, headers = headers, json = problem)
+		create_response = self.http_post(url = create_url, headers = headers, json = problem)
 		
 		create_response.raise_for_status()
 		create_result = create_response.json()
@@ -63,7 +85,7 @@ class QGENAPI:
 		if(status_filter is not None):
 			list_data["status"] = status_filter
 
-		list_response = requests.post(url = list_url, headers = headers, json = list_data)
+		list_response = self.http_post(url = list_url, headers = headers, json = list_data)
 		
 		list_response.raise_for_status()
 		list_result = list_response.json()
@@ -80,7 +102,7 @@ class QGENAPI:
 		status_url = _urljoin(self.qps_api.api_url, "generator", "job", "status")
 		status_data = { "_id": job_id }
 		
-		status_response = requests.post(url = status_url, headers = headers, json = status_data)
+		status_response = self.http_post(url = status_url, headers = headers, json = status_data)
 
 		status_response.raise_for_status()
 		status_result = status_response.json()
@@ -97,7 +119,7 @@ class QGENAPI:
 		stop_url = _urljoin(self.qps_api.api_url, "generator", "job", "stop")
 		stop_data = { "_id": job_id }
 		
-		stop_response = requests.post(url = stop_url, headers = headers, json = stop_data)
+		stop_response = self.http_post(url = stop_url, headers = headers, json = stop_data)
 
 		stop_response.raise_for_status()
 		stop_result = stop_response.json()
@@ -116,7 +138,7 @@ class QGENAPI:
 		if(status_filter is not None):
 			stop_data["status"] = status_filter
 
-		stop_response = requests.post(url = stop_url, headers = headers, json = stop_data)
+		stop_response = self.http_post(url = stop_url, headers = headers, json = stop_data)
 		
 		stop_response.raise_for_status()
 		stop_result = stop_response.json()
@@ -133,7 +155,7 @@ class QGENAPI:
 		start_url = _urljoin(self.qps_api.api_url, "generator", "job", "start")
 		start_data = { "_id": job_id }
 		
-		start_response = requests.post(url = start_url, headers = headers, json = start_data)
+		start_response = self.http_post(url = start_url, headers = headers, json = start_data)
 
 		start_response.raise_for_status()
 		start_result = start_response.json()
@@ -155,7 +177,7 @@ class QGENAPI:
 			status_data = { "_id": job_id }
 			
 			while True:
-				status_response = requests.post(url = status_url, headers = headers, json = status_data)
+				status_response = self.http_post(url = status_url, headers = headers, json = status_data)
 
 				status_response.raise_for_status()
 
@@ -177,7 +199,7 @@ class QGENAPI:
 		#
 		get_job_url = _urljoin(self.qps_api.api_url, "generator", "job", "get")
 		get_job_data = { "_id": job_id }
-		get_job_response = requests.post(url = get_job_url, headers = headers, json = get_job_data)
+		get_job_response = self.http_post(url = get_job_url, headers = headers, json = get_job_data)
 
 		get_job_response.raise_for_status()
 
